@@ -1,12 +1,9 @@
+from joonmyung.draw import data2PIL
+from joonmyung.utils import to_np
 import wandb
 import torch
 import os
 
-from joonmyung.directory.analysis import JDataset
-from joonmyung.draw import data2PIL
-from joonmyung.utils import to_np
-
-
 class AverageMeter:
     ''' Computes and stores the average and current value. '''
     def __init__(self) -> None:
@@ -101,6 +98,7 @@ class Logger():
         wandb.finish()
 
 if __name__ == "__main__":
+    from playground.analysis.utils.dataset import JDataset
     root_path = "/hub_data/joonmyung/data"
     dataset, num_classes, epoch = "cifar100", 10, 1
     data_num = [[5, 1],
@@ -110,13 +108,11 @@ if __name__ == "__main__":
     dataset = JDataset(root_path, dataset)
     inputs, targets, imgs, label_names = dataset.getitems(data_num)
 
-    logger = Logger(use_wandb=True, wandb_entity="joonmyung", wandb_project="test", wandb_table="LOGGGG",
+    logger = Logger(use_wandb=True, wandb_entity="joonmyung", wandb_project="test", wandb_name="LOGGGG",
                     wandb_watch=False)
 
     logger.addLog({ "sample A": [0, 1],
                     "sample B": [0, 2],
                     "sample C": [0, 3],
                     "table  B": [2, {"image" :     inputs, "prediction": targets}]})
-    logger.logWandb()
-
-    print(1)
\ No newline at end of file
+    logger.logWandb()
\ No newline at end of file
